==> foundation-2.6.1.tgz: package/UniversalAccess/UniversalAccess.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const UniversalAccess = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M50 12.5c-20.712 0-37.5 16.793-37.5 37.502C12.5 70.712 29.288 87.5 50 87.5s37.5-16.788 37.5-37.498C87.5 29.293 70.712 12.5 50 12.5zm0 65.061c-15.199 0-27.56-12.362-27.56-27.559C22.44 34.807 34.802 22.44 50 22.44c15.198 0 27.56 12.367 27.56 27.562 0 15.196-12.362 27.559-27.56 27.559z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 49.63,
    cy: 32.546,
    r: 4.723
  }), /*#__PURE__*/React.createElement("path", {
    d: "M65.892 48.189l-8.973-8.974a2.49 2.49 0 00-.089-.089l-.061-.061-.006.006a2.205 2.205 0 00-1.457-.556c-.051 0-.098.012-.148.015H44.703l-.008-.001c-.561 0-1.067.214-1.458.557l-.005-.005-.055.055a1.572 1.572 0 00-.1.1l-8.968 8.968.015.015a1.986 1.986 0 102.808 2.809l.003.003 6.673-6.673v.004a.634.634 0 011.086.443v24.466a2.323 2.323 0 004.645 0V56.935h.017a.643.643 0 111.286 0h.017v12.334a2.323 2.323 0 004.645 0V44.875h.02c-.005-.034-.02-.064-.02-.099 0-.35.284-.633.635-.633a.62.62 0 01.402.155v-.007l.021.021c.015.014.029.027.042.042l6.66 6.661.003-.003a1.986 1.986 0 102.808-2.809l.017-.014z"
  })));
});
UniversalAccess.displayName = 'UniversalAccess';
export const UniversalAccessDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/UniversalAccess/UniversalAccess.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var UniversalAccess = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M50 12.5c-20.712 0-37.5 16.793-37.5 37.502C12.5 70.712 29.288 87.5 50 87.5s37.5-16.788 37.5-37.498C87.5 29.293 70.712 12.5 50 12.5zm0 65.061c-15.199 0-27.56-12.362-27.56-27.559C22.44 34.807 34.802 22.44 50 22.44c15.198 0 27.56 12.367 27.56 27.562 0 15.196-12.362 27.559-27.56 27.559z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 49.63,
    cy: 32.546,
    r: 4.723
  }), /*#__PURE__*/React.createElement("path", {
    d: "M65.892 48.189l-8.973-8.974a2.49 2.49 0 00-.089-.089l-.061-.061-.006.006a2.205 2.205 0 00-1.457-.556c-.051 0-.098.012-.148.015H44.703l-.008-.001c-.561 0-1.067.214-1.458.557l-.005-.005-.055.055a1.572 1.572 0 00-.1.1l-8.968 8.968.015.015a1.986 1.986 0 102.808 2.809l.003.003 6.673-6.673v.004a.634.634 0 011.086.443v24.466a2.323 2.323 0 004.645 0V56.935h.017a.643.643 0 111.286 0h.017v12.334a2.323 2.323 0 004.645 0V44.875h.02c-.005-.034-.02-.064-.02-.099 0-.35.284-.633.635-.633a.62.62 0 01.402.155v-.007l.021.021c.015.014.029.027.042.042l6.66 6.661.003-.003a1.986 1.986 0 102.808-2.809l.017-.014z"
  })));
});
UniversalAccess.displayName = 'UniversalAccess';
export var UniversalAccessDimensions = {
  height: 100,
  width: 100
};
